pygeai.tests.snippets package
=============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.tests.snippets.assistants
   pygeai.tests.snippets.auth
   pygeai.tests.snippets.chat
   pygeai.tests.snippets.dbg
   pygeai.tests.snippets.embeddings
   pygeai.tests.snippets.evaluation
   pygeai.tests.snippets.extras
   pygeai.tests.snippets.files
   pygeai.tests.snippets.gam
   pygeai.tests.snippets.lab
   pygeai.tests.snippets.migrate
   pygeai.tests.snippets.organization
   pygeai.tests.snippets.rerank
   pygeai.tests.snippets.secrets
   pygeai.tests.snippets.usage_limit

Module contents
---------------

.. automodule:: pygeai.tests.snippets
   :members:
   :show-inheritance:
   :undoc-members:
